@@ -5,6 +5,8 @@ ml_train_validation_split <- function(
   x, estimator, estimator_param_maps,
   evaluator,
   train_ratio = 0.75,
+  collect_sub_models = FALSE,
+  parallelism = 1L,
   seed = NULL,
   uid = random_string("train_validation_split_"),
   ...
@@ -17,16 +19,22 @@ ml_train_validation_split.spark_connection <- function(
   x, estimator, estimator_param_maps,
   evaluator,
   train_ratio = 0.75,
+  collect_sub_models = FALSE,
+  parallelism = 1L,
   seed = NULL,
   uid = random_string("train_validation_split_"),
   ...
 ) {
 
   train_ratio <- ensure_scalar_double(train_ratio)
+  collect_sub_models <- ensure_scalar_boolean(collect_sub_models)
+  parallelism <- ensure_scalar_integer(parallelism)
 
   ml_new_validator(x, "org.apache.spark.ml.tuning.TrainValidationSplit", uid,
                    estimator, evaluator, estimator_param_maps, seed) %>%
     invoke("setTrainRatio", train_ratio) %>%
+    jobj_set_param("setCollectSubModels", collect_sub_models, FALSE, "2.3.0") %>%
+    jobj_set_param("setParallelism", parallelism, 1L, "2.3.0") %>%
     new_ml_train_validation_split()
 }
 
@@ -35,6 +43,8 @@ ml_train_validation_split.ml_pipeline <- function(
   x, estimator, estimator_param_maps,
   evaluator,
   train_ratio = 0.75,
+  collect_sub_models = FALSE,
+  parallelism = 1L,
   seed = NULL,
   uid = random_string("train_validation_split_"),
   ...
@@ -48,6 +58,8 @@ ml_train_validation_split.tbl_spark <- function(
   x, estimator, estimator_param_maps,
   evaluator,
   train_ratio = 0.75,
+  collect_sub_models = FALSE,
+  parallelism = 1L,
   seed = NULL,
   uid = random_string("train_validation_split_"),
   ...
@@ -80,6 +92,12 @@ new_ml_train_validation_split_model <- function(jobj) {
       param_maps_to_df() %>%
       dplyr::mutate(!!metric_name := validation_metrics) %>%
       dplyr::select(!!metric_name, dplyr::everything()),
+    sub_models = function() {
+      try_null(jobj %>%
+                 invoke("subModels") %>%
+                 lapply(ml_constructor_dispatch)
+      )
+    },
     subclass = "ml_train_validation_split_model")
 }
 
