@@ -108,14 +108,16 @@ transpose_list <- function(list) {
   do.call(Map, c(c, list, USE.NAMES = FALSE))
 }
 
+#' Random string generation
+#'
+#' Generate a random string with a given prefix.
+#'
+#' @param prefix A length-one character vector.
+#' @export
 random_string <- function(prefix = "table") {
   basename(tempfile(prefix))
 }
 
-"%||%" <- function(x, y) {
-  if (is.null(x)) y else x
-}
-
 is_spark_v2 <- function(scon) {
   spark_version(scon) >= "2.0.0"
 }
