@@ -8,13 +8,11 @@ object LivyUtils {
     "Logger" -> new Logger("", 0),
     "SQLUtils" -> SQLUtils,
     "Utils" -> Utils,
-    "Repartition" -> Repartition,
     "ApplyUtils" -> ApplyUtils,
     "WorkerHelper" -> WorkerHelper,
     "WorkerUtils" -> WorkerUtils,
     "MLUtils" -> MLUtils,
-    "MLUtils2" -> MLUtils2,
-    "BucketizerUtils" -> BucketizerUtils
+    "Shell" -> Shell
    )
 
   val tracker = new JVMObjectTracker()
